@@ -34,7 +34,7 @@ var HTTP = internal.Register(httpBodyContentTypeLexer(MustNewLexer(
 )))
 
 func httpContentBlock(groups []string, lexer Lexer) Iterator {
-	tokens := []*Token{
+	tokens := []Token{
 		{Generic, groups[0]},
 	}
 	return Literator(tokens...)
@@ -42,7 +42,7 @@ func httpContentBlock(groups []string, lexer Lexer) Iterator {
 }
 
 func httpHeaderBlock(groups []string, lexer Lexer) Iterator {
-	tokens := []*Token{
+	tokens := []Token{
 		{Name, groups[1]},
 		{Text, groups[2]},
 		{Operator, groups[3]},
@@ -54,7 +54,7 @@ func httpHeaderBlock(groups []string, lexer Lexer) Iterator {
 }
 
 func httpContinuousHeaderBlock(groups []string, lexer Lexer) Iterator {
-	tokens := []*Token{
+	tokens := []Token{
 		{Text, groups[1]},
 		{Literal, groups[2]},
 		{Text, groups[3]},
@@ -76,57 +76,56 @@ func (d *httpBodyContentTyper) Tokenise(options *TokeniseOptions, text string) (
 		return nil, err
 	}
 
-	return func() *Token {
-		for token := it(); token != nil; token = it() {
-			switch {
-			case token.Type == Name && strings.ToLower(token.Value) == "content-type":
-				{
-					isContentType = true
-				}
-			case token.Type == Literal && isContentType:
-				{
-					isContentType = false
-					contentType = strings.TrimSpace(token.Value)
-					pos := strings.Index(contentType, ";")
-					if pos > 0 {
-						contentType = strings.TrimSpace(contentType[:pos])
-					}
-				}
-			case token.Type == Generic && contentType != "":
-				{
-					lexer := internal.MatchMimeType(contentType)
-
-					// application/calendar+xml can be treated as application/xml
-					// if there's not a better match.
-					if lexer == nil && strings.Contains(contentType, "+") {
-						slashPos := strings.Index(contentType, "/")
-						plusPos := strings.LastIndex(contentType, "+")
-						contentType = contentType[:slashPos+1] + contentType[plusPos+1:]
-						lexer = internal.MatchMimeType(contentType)
-					}
-
-					if lexer == nil {
-						token.Type = Text
-					} else {
-						subIterator, err = lexer.Tokenise(nil, token.Value)
-						if err != nil {
-							panic(err)
-						}
-						return nil
-					}
-				}
+	return func() Token {
+		token := it()
 
+		if token == EOF {
+			if subIterator != nil {
+				return subIterator()
 			}
-
-			return token
+			return EOF
 		}
 
-		if subIterator != nil {
-			for token := subIterator(); token != nil; token = subIterator() {
-				return token
+		switch {
+		case token.Type == Name && strings.ToLower(token.Value) == "content-type":
+			{
+				isContentType = true
 			}
+		case token.Type == Literal && isContentType:
+			{
+				isContentType = false
+				contentType = strings.TrimSpace(token.Value)
+				pos := strings.Index(contentType, ";")
+				if pos > 0 {
+					contentType = strings.TrimSpace(contentType[:pos])
+				}
+			}
+		case token.Type == Generic && contentType != "":
+			{
+				lexer := internal.MatchMimeType(contentType)
+
+				// application/calendar+xml can be treated as application/xml
+				// if there's not a better match.
+				if lexer == nil && strings.Contains(contentType, "+") {
+					slashPos := strings.Index(contentType, "/")
+					plusPos := strings.LastIndex(contentType, "+")
+					contentType = contentType[:slashPos+1] + contentType[plusPos+1:]
+					lexer = internal.MatchMimeType(contentType)
+				}
+
+				if lexer == nil {
+					token.Type = Text
+				} else {
+					subIterator, err = lexer.Tokenise(nil, token.Value)
+					if err != nil {
+						panic(err)
+					}
+					return EOF
+				}
+			}
+
 		}
-		return nil
+		return token
 
 	}, nil
 }
